@@ -1,4 +1,4 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="hi_IN" version="2.1">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="hi_IN">
 <context>
     <name>DAboutDialog</name>
     <message>
@@ -7,12 +7,12 @@
         <translation>आभार</translation>
     </message>
     <message>
-        <location filename="../widgets/dapplication.cpp" line="1238"/>
+        <location filename="../widgets/dapplication.cpp" line="1528"/>
         <source>Version: %1</source>
         <translation>संस्करण : %1</translation>
     </message>
     <message>
-        <location filename="../widgets/dapplication.cpp" line="1242"/>
+        <location filename="../widgets/dapplication.cpp" line="1532"/>
         <source>%1 is released under %2</source>
         <translation>%1, %2 के अंतर्गत विमोचित </translation>
     </message>
@@ -20,87 +20,87 @@
 <context>
     <name>DCrumbEdit</name>
     <message>
-        <location filename="../widgets/dcrumbedit.cpp" line="900"/>
+        <location filename="../widgets/dcrumbedit.cpp" line="840"/>
         <source>Black</source>
         <translation>श्याम</translation>
     </message>
     <message>
-        <location filename="../widgets/dcrumbedit.cpp" line="903"/>
+        <location filename="../widgets/dcrumbedit.cpp" line="843"/>
         <source>White</source>
         <translation>श्वेत</translation>
     </message>
     <message>
-        <location filename="../widgets/dcrumbedit.cpp" line="906"/>
+        <location filename="../widgets/dcrumbedit.cpp" line="846"/>
         <source>Dark Gray</source>
         <translation>गहरा स्लेटी</translation>
     </message>
     <message>
-        <location filename="../widgets/dcrumbedit.cpp" line="909"/>
+        <location filename="../widgets/dcrumbedit.cpp" line="849"/>
         <source>Gray</source>
         <translation>स्लेटी</translation>
     </message>
     <message>
-        <location filename="../widgets/dcrumbedit.cpp" line="912"/>
+        <location filename="../widgets/dcrumbedit.cpp" line="852"/>
         <source>Light Gray</source>
         <translation>हल्का स्लेटी</translation>
     </message>
     <message>
-        <location filename="../widgets/dcrumbedit.cpp" line="915"/>
+        <location filename="../widgets/dcrumbedit.cpp" line="855"/>
         <source>Red</source>
         <translation>लाल</translation>
     </message>
     <message>
-        <location filename="../widgets/dcrumbedit.cpp" line="918"/>
+        <location filename="../widgets/dcrumbedit.cpp" line="858"/>
         <source>Green</source>
         <translation>हरा</translation>
     </message>
     <message>
-        <location filename="../widgets/dcrumbedit.cpp" line="921"/>
+        <location filename="../widgets/dcrumbedit.cpp" line="861"/>
         <source>Blue</source>
         <translation>नीला</translation>
     </message>
     <message>
-        <location filename="../widgets/dcrumbedit.cpp" line="924"/>
+        <location filename="../widgets/dcrumbedit.cpp" line="864"/>
         <source>Cyan</source>
         <translation>हरिनील</translation>
     </message>
     <message>
-        <location filename="../widgets/dcrumbedit.cpp" line="927"/>
+        <location filename="../widgets/dcrumbedit.cpp" line="867"/>
         <source>Magenta</source>
         <translation>गुलाबी</translation>
     </message>
     <message>
-        <location filename="../widgets/dcrumbedit.cpp" line="930"/>
+        <location filename="../widgets/dcrumbedit.cpp" line="870"/>
         <source>Yellow</source>
         <translation>पीला</translation>
     </message>
     <message>
-        <location filename="../widgets/dcrumbedit.cpp" line="933"/>
+        <location filename="../widgets/dcrumbedit.cpp" line="873"/>
         <source>Dark Red</source>
         <translation>गहरा लाल</translation>
     </message>
     <message>
-        <location filename="../widgets/dcrumbedit.cpp" line="936"/>
+        <location filename="../widgets/dcrumbedit.cpp" line="876"/>
         <source>Dark Green</source>
         <translation>गहरा हरा</translation>
     </message>
     <message>
-        <location filename="../widgets/dcrumbedit.cpp" line="939"/>
+        <location filename="../widgets/dcrumbedit.cpp" line="879"/>
         <source>Dark Blue</source>
         <translation>गहरा नीला</translation>
     </message>
     <message>
-        <location filename="../widgets/dcrumbedit.cpp" line="942"/>
+        <location filename="../widgets/dcrumbedit.cpp" line="882"/>
         <source>Dark Cyan</source>
         <translation>गहरा हरिनील</translation>
     </message>
     <message>
-        <location filename="../widgets/dcrumbedit.cpp" line="945"/>
+        <location filename="../widgets/dcrumbedit.cpp" line="885"/>
         <source>Dark Magenta</source>
         <translation>गहरा गुलाबी</translation>
     </message>
     <message>
-        <location filename="../widgets/dcrumbedit.cpp" line="948"/>
+        <location filename="../widgets/dcrumbedit.cpp" line="888"/>
         <source>Dark Yellow</source>
         <translation>गहरा पीला</translation>
     </message>
@@ -121,7 +121,7 @@
 <context>
     <name>DKeySequenceEdit</name>
     <message>
-        <location filename="../widgets/dkeysequenceedit.cpp" line="85"/>
+        <location filename="../widgets/dkeysequenceedit.cpp" line="86"/>
         <source>Enter a new shortcut</source>
         <translation>नया शॉर्टकट दर्ज़ करें</translation>
     </message>
@@ -129,22 +129,22 @@
 <context>
     <name>DLineEdit</name>
     <message>
-        <location filename="../widgets/dlineedit.cpp" line="471"/>
+        <location filename="../widgets/dlineedit.cpp" line="562"/>
         <source>Stop reading</source>
         <translation>पढ़ना बंद करें</translation>
     </message>
     <message>
-        <location filename="../widgets/dlineedit.cpp" line="473"/>
+        <location filename="../widgets/dlineedit.cpp" line="564"/>
         <source>Text to Speech</source>
         <translation>टेक्स्ट से वाणी</translation>
     </message>
     <message>
-        <location filename="../widgets/dlineedit.cpp" line="496"/>
+        <location filename="../widgets/dlineedit.cpp" line="587"/>
         <source>Translate</source>
         <translation>अनुवाद करें</translation>
     </message>
     <message>
-        <location filename="../widgets/dlineedit.cpp" line="518"/>
+        <location filename="../widgets/dlineedit.cpp" line="609"/>
         <source>Speech To Text</source>
         <translation>वाणी से टेक्स्ट</translation>
     </message>
@@ -152,337 +152,337 @@
 <context>
     <name>DPrintPreviewDialogPrivate</name>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="232"/>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="1175"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="235"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="1181"/>
         <source>Advanced</source>
         <translation>विस्तृत</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="255"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="258"/>
         <source>Cancel</source>
         <comment>button</comment>
         <translation>रद्द करें</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="256"/>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="1596"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="259"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="1597"/>
         <source>Print</source>
         <comment>button</comment>
         <translation>प्रिंट</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="272"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="275"/>
         <source>Basic</source>
         <translation>सामान्य</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="287"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="290"/>
         <source>Printer</source>
         <translation>प्रिंटर</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="301"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="304"/>
         <source>Copies</source>
         <translation>प्रतिलिपियाँ</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="321"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="324"/>
         <source>Page range</source>
         <translation>पृष्ठ सीमा</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="323"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="326"/>
         <source>All</source>
         <translation>सभी</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="324"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="327"/>
         <source>Current page</source>
         <translation>वर्तमान पृष्ठ</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="325"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="328"/>
         <source>Select pages</source>
         <translation>पृष्ठ चयन</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="340"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="343"/>
         <source>Orientation</source>
         <translation>अभिविन्यास</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="364"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="367"/>
         <source>Portrait</source>
         <translation>लंबवत अभिविन्यास</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="374"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="377"/>
         <source>Landscape</source>
         <translation>क्षैतिज अभिविन्यास</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="402"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="405"/>
         <source>Pages</source>
         <translation>पृष्ठ</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="412"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="415"/>
         <source>Color mode</source>
         <translation>रंगीन मोड</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="414"/>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="1553"/>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="1620"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="417"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="1554"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="1621"/>
         <source>Color</source>
         <translation>रंग</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="414"/>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="1605"/>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="1620"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="417"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="1606"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="1621"/>
         <source>Grayscale</source>
         <translation>श्वेत-श्याम</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="425"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="428"/>
         <source>Margins</source>
         <translation>सीमांत</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="427"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="430"/>
         <source>Narrow (mm)</source>
         <translation>संकीर्ण (मि॰ मी॰)</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="427"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="430"/>
         <source>Normal (mm)</source>
         <translation>सामान्य (मि॰ मी॰)</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="427"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="430"/>
         <source>Moderate (mm)</source>
         <translation>औसत (मि॰ मी॰)</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="427"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="430"/>
         <source>Customize (mm)</source>
         <translation>अनुकूलित (मि॰ मी॰)</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="433"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="436"/>
         <source>Top</source>
         <translation>शीर्ष</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="436"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="439"/>
         <source>Left</source>
         <translation>बायां</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="439"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="442"/>
         <source>Bottom</source>
         <translation>तल</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="442"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="445"/>
         <source>Right</source>
         <translation>दायां</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="487"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="490"/>
         <source>Scaling</source>
         <translation>अनुमाप परिवर्तन</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="501"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="504"/>
         <source>Actual size</source>
         <translation>वास्तविक आकार</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="510"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="513"/>
         <source>Scale</source>
         <translation>अनुमाप परिवर्तन</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="541"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="544"/>
         <source>Paper</source>
         <translation>पृष्ठ</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="551"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="554"/>
         <source>Paper size</source>
         <translation>पृष्ठ आकार</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="564"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="567"/>
         <source>Print Layout</source>
         <translation>प्रिंट का अभिन्यास</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="575"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="578"/>
         <source>Duplex</source>
         <translation>दोहरा प्रिंट</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="588"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="591"/>
         <source>N-up printing</source>
         <translation>एकल पृष्ठ पर एकाधिक पृष्ठ संयोजन</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="590"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="593"/>
         <source>2 pages/sheet, 1×2</source>
         <translation>2 पृष्ठ/कागज़, 1x2</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="590"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="593"/>
         <source>4 pages/sheet, 2×2</source>
         <translation>4 पृष्ठ/कागज़, 2x2</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="590"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="593"/>
         <source>6 pages/sheet, 2×3</source>
         <translation>6 पृष्ठ/कागज़, 2x3</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="590"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="593"/>
         <source>9 pages/sheet, 3×3</source>
         <translation>9 पृष्ठ/कागज़, 3x3</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="590"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="593"/>
         <source>16 pages/sheet, 4×4</source>
         <translation>16 पृष्ठ/कागज़, 4x4</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="599"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="602"/>
         <source>Layout direction</source>
         <translation>अभिन्यास दिशा</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="644"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="647"/>
         <source>Page Order</source>
         <translation>पृष्ठ क्रम</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="655"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="658"/>
         <source>Collate pages</source>
         <translation>पृष्ठ संयोजन</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="661"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="664"/>
         <source>Print pages in order</source>
         <translation>पृष्ठों को क्रमानुसार प्रिंट करें</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="663"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="666"/>
         <source>Front to back</source>
         <translation>प्रथम से अंतिम</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="663"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="666"/>
         <source>Back to front</source>
         <translation>अंतिम से प्रथम</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="687"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="690"/>
         <source>Watermark</source>
         <translation>वॉटरमार्क</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="698"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="701"/>
         <source>Add watermark</source>
         <translation>वॉटरमार्क जोड़ें</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="740"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="743"/>
         <source>Text watermark</source>
         <translation>शब्द युक्त वॉटरमार्क</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="742"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="745"/>
         <source>Confidential</source>
         <translation>गोपनीय</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="742"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="745"/>
         <source>Draft</source>
         <translation>प्रारूप</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="742"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="745"/>
         <source>Sample</source>
         <translation>नमूना</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="742"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="745"/>
         <source>Custom</source>
         <translation>अनुकूलित</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="750"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="753"/>
         <source>Input your text</source>
         <translation>शब्द दर्ज करें</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="773"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="776"/>
         <source>Picture watermark</source>
         <translation>चित्र युक्त वॉटरमार्क</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="794"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="797"/>
         <source>Layout</source>
         <translation>अभिन्यास</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="796"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="799"/>
         <source>Tile</source>
         <translation>एकाधिक अनुभाग</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="796"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="799"/>
         <source>Center</source>
         <translation>केंद्रित</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="807"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="810"/>
         <source>Angle</source>
         <translation>कोण</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="823"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="826"/>
         <source>Size</source>
         <translation>आकार</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="844"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="847"/>
         <source>Transparency</source>
         <translation>पारदर्शिता</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="901"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="904"/>
         <source>Print to PDF</source>
         <translation>PDF रूप में प्रिंट</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="902"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="905"/>
         <source>Save as Image</source>
         <translation>चित्र के रूप में संचित करें</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="1171"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="1177"/>
         <source>Collapse</source>
         <translation>संक्षिप्त करें</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="1294"/>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="1301"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="1300"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="1307"/>
         <source>Flip on short edge</source>
         <translation>क्षैतिज पृष्ठ क्रम</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="1297"/>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="1300"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="1303"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="1306"/>
         <source>Flip on long edge</source>
         <translation>लंबवत पृष्ठ क्रम</translation>
     </message>
@@ -507,33 +507,33 @@
         <translation>इस प्रकार अल्पविराम दर्ज करें : 1,3,5-7,11-15,18,21</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="1558"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="1559"/>
         <source>Save</source>
         <comment>button</comment>
         <translation>संचित करें</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="2168"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="2174"/>
         <source>*.pdf</source>
-        <translation type="unfinished"/>
+        <translation>*.pdf</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="1672"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="1673"/>
         <source>For example, 1,3,5-7,11-15,18,21</source>
         <translation>उदाहरण, 1,3,5-7,11-15,18,21</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="2168"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="2174"/>
         <source>Save as PDF</source>
         <translation>PDF रूप में संचित</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="2207"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="2213"/>
         <source>Save as image</source>
         <translation>चित्र के रूप में संचित</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewdialog.cpp" line="2209"/>
+        <location filename="../widgets/dprintpreviewdialog.cpp" line="2215"/>
         <source>Images</source>
         <translation>चित्र</translation>
     </message>
@@ -541,20 +541,20 @@
 <context>
     <name>DPrintPreviewWidget</name>
     <message>
-        <location filename="../widgets/dprintpreviewwidget.cpp" line="1590"/>
-        <location filename="../widgets/dprintpreviewwidget.cpp" line="1593"/>
+        <location filename="../widgets/dprintpreviewwidget.cpp" line="1619"/>
+        <location filename="../widgets/dprintpreviewwidget.cpp" line="1622"/>
         <source>Confidential</source>
         <translation>गोपनीय</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewwidget.cpp" line="1608"/>
-        <location filename="../widgets/dprintpreviewwidget.cpp" line="1611"/>
+        <location filename="../widgets/dprintpreviewwidget.cpp" line="1637"/>
+        <location filename="../widgets/dprintpreviewwidget.cpp" line="1640"/>
         <source>Draft</source>
         <translation>प्रारूप</translation>
     </message>
     <message>
-        <location filename="../widgets/dprintpreviewwidget.cpp" line="1626"/>
-        <location filename="../widgets/dprintpreviewwidget.cpp" line="1629"/>
+        <location filename="../widgets/dprintpreviewwidget.cpp" line="1655"/>
+        <location filename="../widgets/dprintpreviewwidget.cpp" line="1658"/>
         <source>Sample</source>
         <translation>नमूना</translation>
     </message>
@@ -562,7 +562,7 @@
 <context>
     <name>DSearchEdit</name>
     <message>
-        <location filename="../widgets/dsearchedit.cpp" line="291"/>
+        <location filename="../widgets/dsearchedit.cpp" line="297"/>
         <source>Search</source>
         <translation>खोजें</translation>
     </message>
@@ -598,25 +598,48 @@
         <translation>कुछ नहीं</translation>
     </message>
 </context>
+<context>
+    <name>DSplitScreenWidget</name>
+    <message>
+        <location filename="../widgets/dtitlebar.cpp" line="215"/>
+        <source>Unmaximize</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../widgets/dtitlebar.cpp" line="218"/>
+        <source>Maximize</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../widgets/dtitlebar.cpp" line="258"/>
+        <source>Tile window to left of screen</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../widgets/dtitlebar.cpp" line="259"/>
+        <source>Tile window to right of screen</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>DTextEdit</name>
     <message>
-        <location filename="../widgets/dtextedit.cpp" line="171"/>
+        <location filename="../widgets/dtextedit.cpp" line="185"/>
         <source>Stop reading</source>
         <translation>पढ़ना बंद करें</translation>
     </message>
     <message>
-        <location filename="../widgets/dtextedit.cpp" line="173"/>
+        <location filename="../widgets/dtextedit.cpp" line="187"/>
         <source>Text to Speech</source>
         <translation>टेक्स्ट से वाणी</translation>
     </message>
     <message>
-        <location filename="../widgets/dtextedit.cpp" line="196"/>
+        <location filename="../widgets/dtextedit.cpp" line="210"/>
         <source>Translate</source>
         <translation>अनुवाद करें</translation>
     </message>
     <message>
-        <location filename="../widgets/dtextedit.cpp" line="218"/>
+        <location filename="../widgets/dtextedit.cpp" line="232"/>
         <source>Speech To Text</source>
         <translation>वाणी से टेक्स्ट</translation>
     </message>
@@ -624,7 +647,7 @@
 <context>
     <name>PickColorWidget</name>
     <message>
-        <location filename="../widgets/dprintpickcolorwidget.cpp" line="109"/>
+        <location filename="../widgets/dprintpickcolorwidget.cpp" line="110"/>
         <source>Color</source>
         <translation>रंग</translation>
     </message>
@@ -632,7 +655,17 @@
 <context>
     <name>QLineEdit</name>
     <message>
-        <location filename="../widgets/dlineedit.cpp" line="454"/>
+        <location filename="../widgets/dlineedit.cpp" line="536"/>
+        <source>&amp;Copy</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../widgets/dlineedit.cpp" line="539"/>
+        <source>Cu&amp;t</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../widgets/dlineedit.cpp" line="545"/>
         <source>Select All</source>
         <translation>सारा चयनित</translation>
     </message>
@@ -640,12 +673,12 @@
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../widgets/dsimplelistview.cpp" line="1334"/>
+        <location filename="../widgets/dsimplelistview.cpp" line="1366"/>
         <source>No search result</source>
         <translation>खोज का परिणाम नहीं मिला</translation>
     </message>
     <message>
-        <location filename="../widgets/private/settings/content.cpp" line="331"/>
+        <location filename="../widgets/private/settings/content.cpp" line="340"/>
         <source>Restore Defaults</source>
         <translation>मूल स्वरूप पुनः स्थापित करें</translation>
     </message>
@@ -653,7 +686,7 @@
 <context>
     <name>QWidgetTextControl</name>
     <message>
-        <location filename="../widgets/dtextedit.cpp" line="163"/>
+        <location filename="../widgets/dtextedit.cpp" line="177"/>
         <source>Select All</source>
         <translation>सारा चयनित</translation>
     </message>
@@ -669,37 +702,42 @@
 <context>
     <name>TitleBarMenu</name>
     <message>
-        <location filename="../widgets/dtitlebar.cpp" line="527"/>
+        <location filename="../widgets/dtitlebar.cpp" line="770"/>
         <source>Theme</source>
         <translation>थीम</translation>
     </message>
     <message>
-        <location filename="../widgets/dtitlebar.cpp" line="529"/>
+        <location filename="../widgets/dtitlebar.cpp" line="772"/>
         <source>Light Theme</source>
         <translation>हल्की थीम</translation>
     </message>
     <message>
-        <location filename="../widgets/dtitlebar.cpp" line="530"/>
+        <location filename="../widgets/dtitlebar.cpp" line="773"/>
         <source>Dark Theme</source>
         <translation>गहरी थीम</translation>
     </message>
     <message>
-        <location filename="../widgets/dtitlebar.cpp" line="531"/>
+        <location filename="../widgets/dtitlebar.cpp" line="774"/>
         <source>System Theme</source>
         <translation>सिस्टम थीम</translation>
     </message>
     <message>
-        <location filename="../widgets/dtitlebar.cpp" line="555"/>
+        <location filename="../widgets/dtitlebar.cpp" line="799"/>
         <source>Help</source>
         <translation>मदद</translation>
     </message>
     <message>
-        <location filename="../widgets/dtitlebar.cpp" line="563"/>
+        <location filename="../widgets/dtitlebar.cpp" line="807"/>
+        <source>Feedback</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../widgets/dtitlebar.cpp" line="814"/>
         <source>About</source>
         <translation>बारे में</translation>
     </message>
     <message>
-        <location filename="../widgets/dtitlebar.cpp" line="570"/>
+        <location filename="../widgets/dtitlebar.cpp" line="821"/>
         <source>Exit</source>
         <translation>बंद करें</translation>
     </message>
