@@ -34,90 +34,63 @@
 DWIDGET_BEGIN_NAMESPACE
 
 /*!
- * \~english \class DArrowRectangle
- * \~english \brief The DArrowRectangle class provides a widget that has an arrow on one
- * \~english of its four borders.
- *
- * \~english It's usually used as a container of some other widgets,
- * \~english see DArrowRectangle::setContent()
+  \class Dtk::Widget::DArrowRectangle
+  \inmodule dtkwidget
+  \brief DArrowRectangle 提供了可以在四个边中的任意一个边显示箭头的矩形控件.
+  \brief The DArrowRectangle class provides a widget that has an arrow on one
+  of its four borders.
+
+  通常用于作为其他控件的容器，将其显示在矩形内作为内容控件
+  It's usually used as a container of some other widgets,
+  see DArrowRectangle::setContent()
+
+  \sa DArrowRectangle::setContent()
  */
 
 /*!
- * \~chinese \class DArrowRectangle
- * \~chinese \brief DArrowRectangle 提供了可以在四个边中的任意一个边显示箭头的矩形控件
- *
- * \~chinese 通常用于作为其他控件的容器，将其显示在矩形内作为内容控件
- * \~chinese \sa DArrowRectangle::setContent()
- */
+  \enum Dtk::Widget::DArrowRectangle::ArrowDirection
+  \brief 箭头方向枚举包含 DArrowRectangle 的箭头可能指向的可能方向.
+  \brief The ArrowDirection enum contains the possible directions that
+  the DArrowRectangle's arrow may point to.
 
-
-
-
-
-/**
- * \~english \enum DArrowRectangle::ArrowDirection
- * \~english \brief The ArrowDirection enum contains the possible directions that
- * \~english the DArrowRectangle's arrow may point to.
- * \~english \var DArrowRectangle::ArrowDirection DArrowRectangle::ArrowLeft
- * \~english indicates the arrow of this rectangle will point left
- * \~english \var DArrowRectangle::ArrowDirection DArrowRectangle::ArrowRight
- * \~english indicates the arrow of this rectangle will point right
- * \~english \var DArrowRectangle::ArrowDirection DArrowRectangle::ArrowTop
- * \~english indicates the arrow of this rectangle will point up
- * \~english \var DArrowRectangle::ArrowDirection DArrowRectangle::ArrowBottom
- * \~english indicates the arrow of this rectangle will point down
- */
-
-/**
- * \~chinese \enum DArrowRectangle::ArrowDirection
- * \~chinese \brief 箭头方向枚举包含 DArrowRectangle 的箭头可能指向的可能方向
- * \~chinese \var DArrowRectangle::ArrowDirection DArrowRectangle::ArrowLeft
- * \~chinese 指示此矩形的箭头将指向左侧
- * \~chinese \var DArrowRectangle::ArrowDirection DArrowRectangle::ArrowRight
- * \~chinese 指示此矩形的箭头将指向右侧
- * \~chinese \var DArrowRectangle::ArrowDirection DArrowRectangle::ArrowTop
- * \~chinese 指示此矩形的箭头将指向上方
- * \~chinese \var DArrowRectangle::ArrowDirection DArrowRectangle::ArrowBottom
- * \~chinese 指示此矩形的箭头将向下指向
+  \value ArrowLeft
+  指示此矩形的箭头将指向左侧
+  indicates the arrow of this rectangle will point left
+  \value ArrowRight
+  指示此矩形的箭头将指向右侧
+  indicates the arrow of this rectangle will point right
+  \value ArrowTop
+  指示此矩形的箭头将指向上方
+  indicates the arrow of this rectangle will point up
+  \value ArrowBottom
+  指示此矩形的箭头将向下指向
+  indicates the arrow of this rectangle will point down
  */
 
 /*!
- * \~english \enum DArrowRectangle::FloatMode
- * \~english \brief The FloatMode enum decide the WindowType when DArrowRectangle show
- * \~english \var DArrowRectangle::FloatMode DArrowRectangle::FloatWindow
- * \~english Window will show a separate window
- * \~english \var DArrowRectangle::FloatMode DArrowRectangle::FloatWidget
- * \~english Widget must by show in the rect of parentWidget
+  \enum Dtk::Widget::DArrowRectangle::FloatMode
+  \brief FloatMode 表示不同的控件的浮动模式
+  \brief The FloatMode enum decide the WindowType when DArrowRectangle show
+  
+  控件的浮动模式表示控件如何显示在布局中，DArrowRectangle::FloatWindow 表示控件将会以一个单独的窗口显示，而 DArrowRectangle::FloatWidget 则表示控件只能显示在其父控件的布局中，不能超出父控件大小
+  
+  \value FloatWindow
+  窗口模式
+  Window will show a separate window
+  \value FloatWidget
+  控件模式
+  Widget must by show in the rect of parentWidget
  */
 
 /*!
- * \~chinese \enum DArrowRectangle::FloatMode
- * \~chinese \brief FloatMode 表示不同的控件的浮动模式
- *
- * \~chinese 控件的浮动模式表示控件如何显示在布局中，DArrowRectangle::FloatWindow 表示控件将会以一个单独的窗口显示，而 DArrowRectangle::FloatWidget 则表示控件只能显示在其父控件的布局中，不能超出父控件大小
- *
- * \~chinese \var DArrowRectangle::FloatMode DArrowRectangle::FloatWindow
- * \~chinese 窗口模式
- * \~chinese \var DArrowRectangle::FloatMode DArrowRectangle::FloatWidget
- * \~chinese 控件模式
- */
+  \brief DArrowRectangle::DArrowRectangle constructs an instance of DArrowRectangle.
+  \brief 获取 DArrowRectangle 实例
 
-
-
-
-
-
-/*!
- * \~english \brief DArrowRectangle::DArrowRectangle constructs an instance of DArrowRectangle.
- * \~english \param direction is used to initialize the direction of which the arrow
- * \~english points to.
- * \~english \param parent is the parent widget the arrow rectangle will be attached to.
- */
-
-/*!
- * \~chinese \brief 获取 DArrowRectangle 实例
- * \~chinese \param direction 用于初始化箭头的方向
- * \~chinese \param parent 作为其父控件
+  \a direction is used to initialize the direction of which the arrow
+  points to.
+  \a parent is the parent widget the arrow rectangle will be attached to.
+  \a direction 用于初始化箭头的方向
+  \a parent 作为其父控件
  */
 DArrowRectangle::DArrowRectangle(ArrowDirection direction, QWidget *parent) :
     QWidget(parent),
@@ -129,19 +102,14 @@ DArrowRectangle::DArrowRectangle(ArrowDirection direction, QWidget *parent) :
 }
 
 /*!
- * \~english \brief DArrowRectangle::DArrowRectangle can set DArrowRectangle show as a window or
- * \~english a widget in parentWidget by floatMode
- * \~english \param direction
- * \~english \param floatMode
- * \~english \param parent
- */
+  \brief 获取 DArrowRectangle 实例，并指定浮动模式.
+  \brief DArrowRectangle::DArrowRectangle can set DArrowRectangle show as a window or
+  a widget in parentWidget by floatMode
 
-/*!
- * \~chinese \brief 获取 DArrowRectangle 实例，并指定浮动模式
- * \~chinese \param direction 用于初始化箭头的方向
- * \~chinese \param floatMode
- * \~chinese \param parent 作为其父控件
- * \~chinese \sa DArrowRectangle::FloatMode
+  \a direction 用于初始化箭头的方向
+  \a floatMode
+  \a parent 作为其父控件
+  \sa DArrowRectangle::FloatMode
  */
 DArrowRectangle::DArrowRectangle(ArrowDirection direction, FloatMode floatMode, QWidget *parent) :
     QWidget(parent),
@@ -152,24 +120,18 @@ DArrowRectangle::DArrowRectangle(ArrowDirection direction, FloatMode floatMode,
     d->init(floatMode);
 }
 
-
 /*!
- * \~english \brief DArrowRectangle::show shows the widget at the given coordinate.
- *
- * \~english \note The coordiate is calculated to be the arrow head's position, so you
- * \~english don't need to calculate the position yourself.
- *
- * \~english \param x is the x coordinate of the arrow head.
- * \~english \param y is the y coordinate of the arrow head.
- */
-
-/*!
- * \~chinese \brief 在指定的坐标位置显示本控件
- *
- * \~chinese \note 坐标被计算为箭头的位置，所以你不需要自己计算箭头位置
- *
- * \~chinese \param x 控件箭头的x轴坐标
- * \~chinese \param y 控件箭头的y轴坐标
+  \brief 在指定的坐标位置显示本控件；
+  \brief DArrowRectangle::show shows the widget at the given coordinate.
+  
+  \note 坐标被计算为箭头的位置，所以你不需要自己计算箭头位置
+  \note The coordiate is calculated to be the arrow head's position, so you
+  don't need to calculate the position yourself.
+  
+  \a x 控件箭头的x轴坐标
+  \a y 控件箭头的y轴坐标
+  \a x is the x coordinate of the arrow head.
+  \a y is the y coordinate of the arrow head.
  */
 void DArrowRectangle::show(int x, int y)
 {
@@ -179,13 +141,10 @@ void DArrowRectangle::show(int x, int y)
 }
 
 /*!
- * \~english \brief DArrowRectangle::setContent sets the content of the arrow rectangle.
- * \~english \param content
- */
+  \brief DArrowRectangle::setContent sets the content of the arrow rectangle.
+  \brief 设置要显示在矩形内的内容控件.
 
-/*!
- * \~chinese \brief 设置要显示在矩形内的内容控件
- * \~chinese \param 要显示内容控件
+  \a content 要显示内容控件
  */
 void DArrowRectangle::setContent(QWidget *content)
 {
@@ -195,8 +154,9 @@ void DArrowRectangle::setContent(QWidget *content)
 }
 
 /*!
- * \~english \brief 获取内容控件
- * \~english \return 正在显示的内容控件
+  \brief 获取内容控件.
+
+  \return 正在显示的内容控件
  */
 QWidget *DArrowRectangle::getContent() const
 {
@@ -206,12 +166,9 @@ QWidget *DArrowRectangle::getContent() const
 }
 
 /*!
- * \~english \brief DArrowRectangle::resizeWithContent automatically adjust the rectangle's
- * \~english size to fit the its content.
- */
-
-/*!
- * \~chinese \brief 根据内容控件的大小自动设置矩形控件的大小
+  \brief 根据内容控件的大小自动设置矩形控件的大小.
+  \brief DArrowRectangle::resizeWithContent automatically adjust the rectangle's
+  size to fit the its content.
  */
 void DArrowRectangle::resizeWithContent()
 {
@@ -221,13 +178,11 @@ void DArrowRectangle::resizeWithContent()
 }
 
 /*!
- * \~english \brief DArrowRectangle::getFixedSize
- * \~english \return the size of the whole widget.
- */
+  \brief 获取整个矩形控件的大小.
+  \brief DArrowRectangle::getFixedSize.
 
-/*!
- * \~chinese \brief 获取整个矩形控件的大小
- * \~chinese \return 矩形控件的大小
+  \return 矩形控件的大小
+  \return the size of the whole widget.
  */
 QSize DArrowRectangle::getFixedSize()
 {
@@ -252,26 +207,20 @@ QSize DArrowRectangle::getFixedSize()
 }
 
 /*!
- * \~english \brief DArrowRectangle::move moves the widget to the coordinate that provided,
- *
- * \~english Like the rules in DArrowRectangle::show(int x, int y), it moves the widget so
- * \~english that the arrow head's coordinate matches the one that provided.
- *
- * \~english \param x is the x coordinate of the arrow head.
- * \~english \param y is the y coordinate of the arrow head.
- *
- * \~english \see DArrowRectangle::show(int x, int y)
- */
+  \brief 移动到指定的坐标位置.
+  \brief DArrowRectangle::move moves the widget to the coordinate that provided,
+  
+  参数的作用类似于 DArrowRectangle::show , 移动整个控件直到箭头出现在参数中指定的坐标
+  Like the rules in DArrowRectangle::show(int x, int y), it moves the widget so
+  that the arrow head's coordinate matches the one that provided.
+  
+  \a x 控件箭头的x轴坐标
+  \a y 控件箭头的y轴坐标
+  \a x is the x coordinate of the arrow head.
+  \a y is the y coordinate of the arrow head.
 
-/*!
- * \~chinese \brief 移动到指定的坐标位置
- *
- * \~chinese 参数的作用类似于 DArrowRectangle::show , 移动整个控件直到箭头出现在参数中指定的坐标
- *
- * \~chinese \param x 控件箭头的x轴坐标
- * \~chinese \param y 控件箭头的y轴坐标
- *
- * \~chinese \sa DArrowRectangle::show
+  \sa DArrowRectangle::show(int x, int y)
+  \sa DArrowRectangle::show
  */
 void DArrowRectangle::move(int x, int y)
 {
@@ -334,16 +283,14 @@ const QRect DArrowRectanglePrivate::currentScreenRect(const int x, const int y)
 }
 
 /*!
- * \~english \property DArrowRectangle::shadowYOffset
- * \~english \brief the offset of the widget and its shadow on y axis.
- */
+  \property DArrowRectangle::shadowYOffset
+  \property DArrowRectangle::shadowYOffset
 
-/*!
- * \~chinese \property DArrowRectangle::shadowYOffset
- * \~chinese \brief 这属性表示小部件及其阴影在y轴上的偏移量
- *
- * \~chinese Getter: DArrowRectangle::shadowYOffset Setter: DArrowRectangle::setShadowYOffset
- * \~chinese \sa DArrowRectangle::shadowXOffset
+  \brief 这属性表示小部件及其阴影在y轴上的偏移量.
+  \brief the offset of the widget and its shadow on y axis.
+
+  Getter: DArrowRectangle::shadowYOffset Setter: DArrowRectangle::setShadowYOffset
+  \sa DArrowRectangle::shadowXOffset
  */
 qreal DArrowRectangle::shadowYOffset() const
 {
@@ -352,9 +299,6 @@ qreal DArrowRectangle::shadowYOffset() const
     return d->m_shadowYOffset;
 }
 
-/**
- * \~chinese \sa DArrowRectangle::shadowYOffset
- */
 void DArrowRectangle::setShadowYOffset(const qreal &shadowYOffset)
 {
     D_D(DArrowRectangle);
@@ -367,7 +311,9 @@ void DArrowRectangle::setShadowYOffset(const qreal &shadowYOffset)
 }
 
 /*!
- * \~chinese \brief DArrowRectangle::setLeftRightRadius 设置左右箭头时的圆角
+  \brief DArrowRectangle::setLeftRightRadius 设置左右箭头时的圆角.
+
+  \a enable 是否开启.
  */
 void DArrowRectangle::setLeftRightRadius(bool enable)
 {
@@ -376,7 +322,9 @@ void DArrowRectangle::setLeftRightRadius(bool enable)
 }
 
 /*!
- * \~chinese \brief DArrowRectangle::setArrowStyleEnable 设置圆角箭头样式
+  \brief DArrowRectangle::setArrowStyleEnable 设置圆角箭头样式.
+
+  \a enable 是否开启.
  */
 void DArrowRectangle::setRadiusArrowStyleEnable(bool enable)
 {
@@ -387,16 +335,13 @@ void DArrowRectangle::setRadiusArrowStyleEnable(bool enable)
 }
 
 /*!
- * \~english \property DArrowRectangle::shadowXOffset
- * \~english \brief the offset of the widget and its shadow on x axis.
- */
+  \property DArrowRectangle::shadowXOffset
 
-/*!
- * \~chinese \property DArrowRectangle::shadowXOffset
- * \~chinese \brief 这属性表示小部件及其阴影在x轴上的偏移量
- *
- * \~chinese Getter: DArrowRectangle::shadowXOffset Setter: DArrowRectangle::setShadowXOffset
- * \~chinese \sa DArrowRectangle::shadowYOffset
+  \brief 这属性表示小部件及其阴影在x轴上的偏移量
+  \brief the offset of the widget and its shadow on x axis.
+  
+  Getter: DArrowRectangle::shadowXOffset Setter: DArrowRectangle::setShadowXOffset
+  \sa DArrowRectangle::shadowYOffset
  */
 qreal DArrowRectangle::shadowXOffset() const
 {
@@ -405,9 +350,6 @@ qreal DArrowRectangle::shadowXOffset() const
     return d->m_shadowXOffset;
 }
 
-/**
- * \~chinese \sa DArrowRectangle::shadowXOffset
- */
 void DArrowRectangle::setShadowXOffset(const qreal &shadowXOffset)
 {
     D_D(DArrowRectangle);
@@ -420,16 +362,12 @@ void DArrowRectangle::setShadowXOffset(const qreal &shadowXOffset)
 }
 
 /*!
- * \~english \property DArrowRectangle::shadowBlurRadius
- * \~english \brief This property holds the blur radius of the widget's shadow.
- */
+  \property DArrowRectangle::shadowBlurRadius
 
-/*!
- * \~chinese \property DArrowRectangle::shadowBlurRadius
- * \~chinese \brief 这个属性保存小部件阴影的模糊半径
- *
- * \~chinese Getter: DArrowRectangle::shadowBlurRadius Setter: DArrowRectangle::setShadowBlurRadius
- * \~chinese \sa DArrowRectangle::shadowBlurRadius
+  \brief 这个属性保存小部件阴影的模糊半径
+  \brief This property holds the blur radius of the widget's shadow.
+  
+  Getter: DArrowRectangle::shadowBlurRadius Setter: DArrowRectangle::setShadowBlurRadius
  */
 qreal DArrowRectangle::shadowBlurRadius() const
 {
@@ -438,9 +376,6 @@ qreal DArrowRectangle::shadowBlurRadius() const
     return d->m_shadowBlurRadius;
 }
 
-/*!
- * \~chinese \sa DArrowRectangle::setShadowBlurRadius
- */
 void DArrowRectangle::setShadowBlurRadius(const qreal &shadowBlurRadius)
 {
     D_D(DArrowRectangle);
@@ -453,15 +388,12 @@ void DArrowRectangle::setShadowBlurRadius(const qreal &shadowBlurRadius)
 }
 
 /*!
- * \~english \property DArrowRectangle::borderColor
- * \~english \brief This property holds the border color of this widget.
- */
+  \property DArrowRectangle::borderColor
 
-/*!
- * \~chinese \property DArrowRectangle::borderColor
- * \~chinese \brief 这个属性表示控件边框的颜色
- *
- * \~chinese Getter: DArrowRectangle::borderColor , Setter: DArrowRectangle::setBorderColor
+  \brief 这个属性表示控件边框的颜色
+  \brief This property holds the border color of this widget.
+  
+  Getter: DArrowRectangle::borderColor , Setter: DArrowRectangle::setBorderColor
  */
 QColor DArrowRectangle::borderColor() const
 {
@@ -470,9 +402,6 @@ QColor DArrowRectangle::borderColor() const
     return d->m_borderColor;
 }
 
-/*!
- * \~chinese \sa DArrowRectangle::borderColor
- */
 void DArrowRectangle::setBorderColor(const QColor &borderColor)
 {
     D_D(DArrowRectangle);
@@ -485,15 +414,12 @@ void DArrowRectangle::setBorderColor(const QColor &borderColor)
 }
 
 /*!
- * \~english \property DArrowRectangle::borderWidth
- * \~english \brief This property holds the border width of this widget.
- */
+  \property DArrowRectangle::borderWidth
 
-/*!
- * \~chinese \property DArrowRectangle::borderWidth
- * \~chinese \brief 这个属性表示控件边框的宽度
- *
- * \~chinese Getter: DArrowRectangle::borderWidth , Setter: DArrowRectangle::setBorderWidth
+  \brief 这个属性表示控件边框的宽度
+  \brief This property holds the border width of this widget.
+  
+  Getter: DArrowRectangle::borderWidth , Setter: DArrowRectangle::setBorderWidth
  */
 int DArrowRectangle::borderWidth() const
 {
@@ -502,9 +428,6 @@ int DArrowRectangle::borderWidth() const
     return d->m_borderWidth;
 }
 
-/*!
- * \~chinese \sa DArrowRectangle::borderWidth
- */
 void DArrowRectangle::setBorderWidth(int borderWidth)
 {
     D_D(DArrowRectangle);
@@ -517,15 +440,12 @@ void DArrowRectangle::setBorderWidth(int borderWidth)
 }
 
 /*!
- * \~english \property DArrowRectangle::backgroundColor
- * \~english \brief the background color of this rectangle.
- */
+  \property DArrowRectangle::backgroundColor
 
-/*!
- * \~chinese \property DArrowRectangle::backgroundColor
- * \~chinese \brief 这个属性表示矩形控件的背景颜色
- *
- * \~chinese Getter: DArrowRectangle::backgroundColor , Setter: DArrowRectangle::setBackgroundColor
+  \brief 这个属性表示矩形控件的背景颜色
+  \brief the background color of this rectangle.
+  
+  Getter: DArrowRectangle::backgroundColor , Setter: DArrowRectangle::setBackgroundColor
  */
 QColor DArrowRectangle::backgroundColor() const
 {
@@ -535,15 +455,12 @@ QColor DArrowRectangle::backgroundColor() const
 }
 
 /*!
- * \~english \property DArrowRectangle::arrowDirection
- * \~english \brief This property holds the direction of the rectangle's arrow points to.
- */
+  \property DArrowRectangle::arrowDirection
 
-/*!
- * \~chinese \property DArrowRectangle::arrowDirection
- * \~chinese \brief 这个属性表示箭头的方向
- *
- * \~chinese Getter: DArrowRectangle::arrowDirection , Setter: DArrowRectangle::setArrowDirection
+  \brief This property holds the direction of the rectangle's arrow points to.
+  \brief 这个属性表示箭头的方向
+  
+  Getter: DArrowRectangle::arrowDirection , Setter: DArrowRectangle::setArrowDirection
  */
 DArrowRectangle::ArrowDirection DArrowRectangle::arrowDirection() const
 {
@@ -552,9 +469,6 @@ DArrowRectangle::ArrowDirection DArrowRectangle::arrowDirection() const
     return d->m_arrowDirection;
 }
 
-/*!
- * \~chinese \sa DArrowRectangle::backgroundColor
- */
 void DArrowRectangle::setBackgroundColor(const QColor &backgroundColor)
 {
     D_D(DArrowRectangle);
@@ -582,21 +496,15 @@ void DArrowRectangle::setBackgroundColor(const QColor &backgroundColor)
 }
 
 /*!
- * \~english \brief DArrowRectangle::setBackgroundColor is an overloaded function.
- *
- * \~english It sets the background color by modifing the mask color of the
- * \~english Dtk::Widget::DBlurEffectWidget.
- *
- * \~english \param type is the mask color to set.
- */
+  \brief DArrowRectangle::setBackgroundColor is an overloaded function.
+  \brief DArrowRectangle::setBackgroundColor 是一个重载方法
+  
+  通过改变 DBlurEffectWidget::MaskColorType 来修改控件矩形的背景
+  It sets the background color by modifing the mask color of the
+  Dtk::Widget::DBlurEffectWidget.
 
-/*!
- * \~chinese \brief DArrowRectangle::setBackgroundColor 是一个重载方法
- *
- * \~chinese 通过改变 DBlurEffectWidget::MaskColorType 来修改控件矩形的背景
- *
- * \~chinese \param type is the mask color to set.
- * \~chinese \sa DArrowRectangle::backgroundColor and DBlurEffectWidget::MaskColorType
+  \a type is the mask color to set.
+  \sa DArrowRectangle::backgroundColor DBlurEffectWidget::MaskColorType
  */
 void DArrowRectangle::setBackgroundColor(DBlurEffectWidget::MaskColorType type)
 {
@@ -608,15 +516,12 @@ void DArrowRectangle::setBackgroundColor(DBlurEffectWidget::MaskColorType type)
 }
 
 /*!
- * \~english \property DArrowRectangle::radius
- * \~english \brief radius of the rectangle
- */
+  \property DArrowRectangle::radius
 
-/*!
- * \~chinese \property DArrowRectangle::radius
- * \~chinese \brief 这个属性表示矩形的圆角
- *
- * \~chinese Getter: DArrowRectangle::radius , Setter: DArrowRectangle::setRadius
+  \brief 这个属性表示矩形的圆角
+  \brief radius of the rectangle
+  
+  Getter: DArrowRectangle::radius , Setter: DArrowRectangle::setRadius
  */
 int DArrowRectangle::radius() const
 {
@@ -626,16 +531,13 @@ int DArrowRectangle::radius() const
 }
 
 /*!
- * \~english \property DArrowRectangle::arrowHeight
- * \~english \brief height of rectangle's arrow
- */
+  \property DArrowRectangle::arrowHeight
 
-/*!
- * \~chinese \property DArrowRectangle::arrowHeight
- * \~chinese \brief 这个属性表示箭头的高度
- *
- * \~chinese Getter: DArrowRectangle::arrowHeight , Setter: DArrowRectangle::setArrowHeight
- * \~chinese \sa DArrowRectangle::arrowWidth
+  \brief height of rectangle's arrow
+  \brief 这个属性表示箭头的高度
+  
+  Getter: DArrowRectangle::arrowHeight , Setter: DArrowRectangle::setArrowHeight
+  \sa DArrowRectangle::arrowWidth
  */
 int DArrowRectangle::arrowHeight() const
 {
@@ -645,16 +547,13 @@ int DArrowRectangle::arrowHeight() const
 }
 
 /*!
- * \~english \property DArrowRectangle::arrowWidth
- * \~english \brief width of the rectangle's arrow
- */
+  \property DArrowRectangle::arrowWidth
 
-/*!
- * \~chinese \property DArrowRectangle::arrowWidth
- * \~chinese \brief 这个属性表示箭头的宽度
- *
- * \~chinese Getter: DArrowRectangle::arrowWidth , Setter: DArrowRectangle::setArrowWidth
- * \~chinese \sa DArrowRectangle::arrowHeight
+  \brief 这个属性表示箭头的宽度
+  \brief width of the rectangle's arrow
+  
+  Getter: DArrowRectangle::arrowWidth , Setter: DArrowRectangle::setArrowWidth
+  \sa DArrowRectangle::arrowHeight
  */
 int DArrowRectangle::arrowWidth() const
 {
@@ -664,16 +563,13 @@ int DArrowRectangle::arrowWidth() const
 }
 
 /*!
- * \~english \property DArrowRectangle::arrowX
- * \~english \brief the x coordinate of the rectangle's arrow
- */
+  \property DArrowRectangle::arrowX
 
-/*!
- * \~chinese \property DArrowRectangle::arrowX
- * \~chinese \brief 这个属性表示箭头的x轴坐标
- *
- * \~chinese Getter: DArrowRectangle::arrowX , Setter: DArrowRectangle::setArrowX
- * \~chinese \sa DArrowRectangle::arrowY
+  \brief the x coordinate of the rectangle's arrow
+  \brief 这个属性表示箭头的x轴坐标
+  
+  Getter: DArrowRectangle::arrowX , Setter: DArrowRectangle::setArrowX
+  \sa DArrowRectangle::arrowY
  */
 int DArrowRectangle::arrowX() const
 {
@@ -683,16 +579,13 @@ int DArrowRectangle::arrowX() const
 }
 
 /*!
- * \~english \property DArrowRectangle::arrowY
- * \~english \brief the y coordinate of the rectangle's arrow
- */
+  \property DArrowRectangle::arrowY
 
-/*!
- * \~chinese \property DArrowRectangle::arrowY
- * \~chinese \brief 这个属性表示箭头的y轴坐标
- *
- * \~chinese Getter: DArrowRectangle::arrowY , Setter: DArrowRectangle::setArrowY
- * \~chinese \sa DArrowRectangle::arrowX
+  \brief 这个属性表示箭头的y轴坐标
+  \brief the y coordinate of the rectangle's arrow
+  
+  Getter: DArrowRectangle::arrowY , Setter: DArrowRectangle::setArrowY
+  \sa DArrowRectangle::arrowX
  */
 int DArrowRectangle::arrowY() const
 {
@@ -702,22 +595,18 @@ int DArrowRectangle::arrowY() const
 }
 
 /*!
- * \~english \property DArrowRectangle::margin
- * \~english \brief This property holds the width of the margin
- *
- * \~english The margin is the distance between the innermost pixel of the rectangle and the
- * \~english outermost pixel of its contents.
- *
- * \~english The default margin is 0.
- */
+  \property DArrowRectangle::margin
 
-/*!
- * \~chinese \property DArrowRectangle::margin
- * \~chinese \brief 这个属性表示边距大小
- *
- * \~chinese 边距是指矩形最里面的像素与其内容最外面的像素之间的距离
- * \~chinese Getter: DArrowRectangle::margin , Setter: DArrowRectangle::setMargin
- * \~chinese \sa DArrowRectangle::margin
+  \brief 这个属性表示边距大小
+  \brief This property holds the width of the margin
+  
+  The margin is the distance between the innermost pixel of the rectangle and the
+  outermost pixel of its contents.
+  The default margin is 0.
+  边距是指矩形最里面的像素与其内容最外面的像素之间的距离
+  Getter: DArrowRectangle::margin , Setter: DArrowRectangle::setMargin
+
+  \sa DArrowRectangle::setMargin
  */
 int DArrowRectangle::margin() const
 {
@@ -727,7 +616,11 @@ int DArrowRectangle::margin() const
 }
 
 /*!
- * \~chinese \sa DArrowRectangle::arrowDirection
+  \brief 该函数用于设置箭头方向.
+
+  \a value 箭头方向.
+
+  \sa DArrowRectangle::arrowDirection
  */
 void DArrowRectangle::setArrowDirection(ArrowDirection value)
 {
@@ -736,28 +629,32 @@ void DArrowRectangle::setArrowDirection(ArrowDirection value)
     d->m_arrowDirection = value;
 }
 
-/**
- * \~chinese \brief 设置整个控件固定的宽度
- * \~chinese
- * \~chinese \param value 宽度大小
+/*!
+  \brief 该函数用于设置整个控件固定的宽度
+  
+  \a value 宽度大小
  */
 void DArrowRectangle::setWidth(int value)
 {
     setFixedWidth(value);
 }
 
-/**
- * \~chinese \brief 设置整个控件固定的高度
- * \~chinese
- * \~chinese \param value 高度大小
+/*!
+  \brief 设置整个控件固定的高度
+  
+  \a value 高度大小
  */
 void DArrowRectangle::setHeight(int value)
 {
     setFixedHeight(value);
 }
 
-/**
- * \~chinese \sa DArrowRectangle::radius
+/*!
+  \brief 该函数用于设置圆角大小.
+
+  \a value 圆角大小.
+
+  \sa DArrowRectangle::radius
  */
 void DArrowRectangle::setRadius(int value)
 {
@@ -766,8 +663,12 @@ void DArrowRectangle::setRadius(int value)
     d->m_radius = value;
 }
 
-/**
- * \~chinese \sa DArrowRectangle::arrowHeight
+/*!
+  \brief 设置箭头高度.
+
+  \a value 箭头高度.
+
+  \sa DArrowRectangle::arrowHeight
  */
 void DArrowRectangle::setArrowHeight(int value)
 {
@@ -776,8 +677,12 @@ void DArrowRectangle::setArrowHeight(int value)
     d->m_arrowHeight = value;
 }
 
-/**
- * \~chinese \sa DArrowRectangle::arrowWidth
+/*!
+  \brief 设置箭头宽度.
+
+  \a value 箭头宽度.
+
+  \sa DArrowRectangle::arrowWidth
  */
 void DArrowRectangle::setArrowWidth(int value)
 {
@@ -786,8 +691,12 @@ void DArrowRectangle::setArrowWidth(int value)
     d->m_arrowWidth = value;
 }
 
-/**
- * \~chinese \sa DArrowRectangle::arrowX
+/*!
+  \brief 设置箭头 x 坐标的值.
+
+  \a value x 坐标的值.
+
+  \sa DArrowRectangle::arrowX
  */
 void DArrowRectangle::setArrowX(int value)
 {
@@ -796,8 +705,12 @@ void DArrowRectangle::setArrowX(int value)
     d->m_arrowX = value;
 }
 
-/**
- * \~chinese \sa DArrowRectangle::arrowY
+/*!
+  \brief 设置箭头 y 坐标的值.
+
+  \a value y 坐标的值.
+
+  \sa DArrowRectangle::arrowY
  */
 void DArrowRectangle::setArrowY(int value)
 {
@@ -806,8 +719,12 @@ void DArrowRectangle::setArrowY(int value)
     d->m_arrowY = value;
 }
 
-/**
- * \~chinese \sa DArrowRectangle::margin
+/*!
+  \brief 设置边距大小.
+
+  \a value 边距大小.
+
+  \sa DArrowRectangle::margin
  */
 void DArrowRectangle::setMargin(int value)
 {
@@ -827,9 +744,13 @@ QPainterPath DArrowRectanglePrivate::getLeftCornerPath()
 
         if (DApplication::isDXcbPlatform())
             rect = rect.marginsRemoved(QMargins((DArrowRectangle::FloatWidget == floatMode) ? 0 : delta, delta, delta - q->margin(), delta));
-        else
-            rect = rect.marginsRemoved(QMargins((DArrowRectangle::FloatWidget == floatMode) ? 0 : 0, delta,
-                                                (DArrowRectangle::FloatWidget == floatMode) ? delta - q->margin() : delta *2, delta));
+        else {
+            QMargins margins((DArrowRectangle::FloatWidget == floatMode) ? 0 : 0, delta,
+                             (DArrowRectangle::FloatWidget == floatMode) ? delta - q->margin() : delta *2, delta);
+            if (rect.width() > (margins.left() + margins.right()) &&
+                rect.height() > (margins.top() + margins.bottom()))
+                rect = rect.marginsRemoved(margins);
+        }
     }
 
     QPoint cornerPoint(rect.x(), rect.y() + (m_arrowY > 0 ? m_arrowY : (rect.height() / 2)));
@@ -910,8 +831,12 @@ QPainterPath DArrowRectanglePrivate::getRightCornerPath()
 
         if (DApplication::isDXcbPlatform())
             rect = rect.marginsRemoved(QMargins((DArrowRectangle::FloatWidget == floatMode) ? delta - q->margin() : delta, delta, (DArrowRectangle::FloatWidget == floatMode) ? 0 : delta, delta));
-        else
-            rect = rect.marginsRemoved(QMargins((DArrowRectangle::FloatWidget == floatMode) ? delta -q->margin() : delta *2, delta, (DArrowRectangle::FloatWidget == floatMode) ? 0 : 0, delta));
+        else {
+            QMargins margins((DArrowRectangle::FloatWidget == floatMode) ? delta -q->margin() : delta *2, delta, (DArrowRectangle::FloatWidget == floatMode) ? 0 : 0, delta);
+            if (rect.width() > (margins.left() + margins.right()) &&
+                rect.height() > (margins.top() + margins.bottom()))
+                rect = rect.marginsRemoved(margins);
+        }
     }
 
     QPoint cornerPoint(rect.x() + rect.width(), rect.y() + (m_arrowY > 0 ? m_arrowY : rect.height() / 2));
@@ -994,8 +919,12 @@ QPainterPath DArrowRectanglePrivate::getTopCornerPath()
         if (DApplication::isDXcbPlatform())
             rect = rect.marginsRemoved(QMargins(delta, (DArrowRectangle::FloatWidget == floatMode) ? 0 : delta,
                                                 delta, (DArrowRectangle::FloatWidget == floatMode) ? delta -q->margin() : delta));
-        else
-            rect = rect.marginsRemoved(QMargins(delta, 0, delta, (DArrowRectangle::FloatWidget == floatMode) ? delta - q->margin() : delta * 2));
+        else {
+            QMargins margins(delta, 0, delta, (DArrowRectangle::FloatWidget == floatMode) ? delta - q->margin() : delta * 2);
+            if (rect.width() > (margins.left() + margins.right()) &&
+                rect.height() > (margins.top() + margins.bottom()))
+                rect = rect.marginsRemoved(margins);
+        }
     }
 
     QPoint cornerPoint(rect.x() + (m_arrowX > 0 ? m_arrowX : rect.width() / 2), rect.y());
@@ -1054,8 +983,12 @@ QPainterPath DArrowRectanglePrivate::getBottomCornerPath()
 
         if (DApplication::isDXcbPlatform())
             rect = rect.marginsRemoved(QMargins(delta, (DArrowRectangle::FloatWidget == floatMode) ? delta -q->margin() : delta, delta, (DArrowRectangle::FloatWidget == floatMode) ? 0 : delta));
-        else
-            rect = rect.marginsRemoved(QMargins(delta, (DArrowRectangle::FloatWidget == floatMode) ? delta - q->margin() : delta *2, delta, 0));
+        else {
+            QMargins margins(delta, (DArrowRectangle::FloatWidget == floatMode) ? delta - q->margin() : delta *2, delta, 0);
+            if (rect.width() > (margins.left() + margins.right()) &&
+                rect.height() > (margins.top() + margins.bottom()))
+                rect = rect.marginsRemoved(margins);
+        }
     }
 
     QPoint cornerPoint(rect.x() + (m_arrowX > 0 ? m_arrowX : qRound(double(rect.width()) / 2)), rect.y() + rect.height());
@@ -1207,6 +1140,10 @@ void DArrowRectanglePrivate::updateClipPath()
 
 bool DArrowRectanglePrivate::radiusEnabled()
 {
+    D_Q(DArrowRectangle);
+    if (q->property("_d_radius_force").toBool())
+        return true;
+
     if (m_wmHelper && !m_wmHelper->hasComposite()) {
         return false;
     }
@@ -1258,7 +1195,10 @@ void DArrowRectanglePrivate::init(DArrowRectangle::FloatMode mode)
 
         m_wmHelper = DWindowManagerHelper::instance();
 
-        q->connect(m_wmHelper, &DWindowManagerHelper::hasCompositeChanged, q, static_cast<void (DArrowRectangle::*)()>(&DArrowRectangle::update), Qt::QueuedConnection);
+        q->connect(m_wmHelper, &DWindowManagerHelper::hasCompositeChanged, q, [q, this](){
+            q->update();
+            this->updateClipPath();
+        }, Qt::QueuedConnection);
     } else {
         DGraphicsGlowEffect *glowEffect = new DGraphicsGlowEffect;
         glowEffect->setBlurRadius(q->shadowBlurRadius());
