@@ -14,6 +14,7 @@
 #include <DStyle>
 
 #include <QVBoxLayout>
+#include "private/qkeymapper_p.h"
 
 DWIDGET_BEGIN_NAMESPACE
 
@@ -28,7 +29,7 @@ public:
         QVBoxLayout *layout = new QVBoxLayout(this);
         layout->setContentsMargins(layout->contentsMargins().left(), 0, layout->contentsMargins().right(), 0);
         layout->setSpacing(0);
-        label->setForegroundRole(QPalette::Highlight);
+        label->setForegroundRole(QPalette::ButtonText);
         layout->addWidget(label);
     }
 
@@ -150,8 +151,8 @@ protected:
 };
 
 /*!
- * \~chinese \brief DKeySequenceEdit::DKeySequenceEdit 一个快捷键编辑展示的控件
- * \~chinese \param parent
+  \brief DKeySequenceEdit::DKeySequenceEdit 一个快捷键编辑展示的控件
+  \a parent
  */
 DKeySequenceEdit::DKeySequenceEdit(QWidget *parent)
     : QLineEdit(parent)
@@ -163,7 +164,7 @@ DKeySequenceEdit::DKeySequenceEdit(QWidget *parent)
 }
 
 /*!
- * \~chinese \brief DKeySequenceEdit::clear 清空内容
+  \brief DKeySequenceEdit::clear 清空内容
  */
 void DKeySequenceEdit::clear()
 {
@@ -175,9 +176,9 @@ void DKeySequenceEdit::clear()
 }
 
 /*!
- * \~chinese \brief DKeySequenceEdit::setKeySequence 设定快捷键
- * \~chinese \param keySequence 快捷键
- * \~chinese \return true设定成功　false设定失败
+  \brief DKeySequenceEdit::setKeySequence 设定快捷键
+  \a keySequence 快捷键
+  \return true设定成功　false设定失败
  */
 bool DKeySequenceEdit::setKeySequence(const QKeySequence &keySequence)
 {
@@ -205,8 +206,8 @@ bool DKeySequenceEdit::setKeySequence(const QKeySequence &keySequence)
 }
 
 /*!
- * \~chinese \brief DKeySequenceEdit::keySequence 返回设定的快捷键
- * \~chinese \return
+  \brief DKeySequenceEdit::keySequence 返回设定的快捷键
+  \return
  */
 QKeySequence DKeySequenceEdit::keySequence()
 {
@@ -215,8 +216,8 @@ QKeySequence DKeySequenceEdit::keySequence()
 }
 
 /*!
- * \~chinese \brief DKeySequenceEdit::ShortcutDirection　快捷键文本展示方向
- * \~chinese \param alig 设定方向的枚举值
+  \brief DKeySequenceEdit::ShortcutDirection　快捷键文本展示方向
+  \a alig 设定方向的枚举值
  */
 void DKeySequenceEdit::ShortcutDirection(Qt::AlignmentFlag alig)
 {
@@ -227,8 +228,8 @@ void DKeySequenceEdit::ShortcutDirection(Qt::AlignmentFlag alig)
 }
 
 /*!
- * \~chinese \brief DKeySequenceEdit::getKeySequence 将Qt快捷键文案转换为Dtk文案
- * \~chinese \return Dtk文案
+  \brief DKeySequenceEdit::getKeySequence 将Qt快捷键文案转换为Dtk文案
+  \return Dtk文案
  */
 QString DKeySequenceEdit::getKeySequence(QKeySequence sequence)
 {
@@ -254,8 +255,27 @@ void DKeySequenceEdit::keyPressEvent(QKeyEvent *e)
         return;
     }
 
+    if (e->modifiers() & Qt::ShiftModifier) {
+        QList<int> possibleKeys = QKeyMapper::possibleKeys(e);
+        int pkTotal = possibleKeys.count();
+        if (!pkTotal)
+            return;
+        bool found = false;
+        for (int i = 0; i < possibleKeys.size(); ++i) {
+            if (possibleKeys.at(i) - nextKey == int(e->modifiers())
+                || (possibleKeys.at(i) == nextKey && e->modifiers() == Qt::ShiftModifier)) {
+                nextKey = possibleKeys.at(i);
+                found = true;
+                break;
+            }
+        }
+        // Use as fallback
+        if (!found)
+            nextKey = possibleKeys.first();
+    }
+
     QString modifiers = QKeySequence(e->modifiers()).toString();
-    QString key =  QKeySequence(e->key()).toString();
+    QString key =  QKeySequence(nextKey).toString();
 
     QKeySequence sequence(modifiers + key);
     bool flags = setKeySequence(sequence);
