@@ -39,16 +39,28 @@
 DWIDGET_BEGIN_NAMESPACE
 
 /*!
- * \~chinese \class DLineEdit
- * \~chinese \brief DLineEdit一个聚合 QLineEdit 的输入框
- * \~chinese \li DLineEdit提供了向输入框左右两端插入控件的函数
- * \~chinese \li DLineEdit提供了带警告颜色的输入框
- * \~chinese \li DLineEdit提供了带文本警告消息的输入框
+  \class Dtk::Widget::DLineEdit
+  \inmodule dtkwidget
+  \brief DLineEdit一个聚合 QLineEdit 的输入框.
+
+  \list
+  \li DLineEdit提供了向输入框左右两端插入控件的函数
+  \li DLineEdit提供了带警告颜色的输入框
+  \li DLineEdit提供了带文本警告消息的输入框
+  \endlist
  */
 
 /*!
- * \~chinese \brief DLineEdit的构造函数
- * \~chinese \param parent参数被发送到 QWidget 构造函数。
+    \property DLineEdit::alert
+
+    \brief 警告模式属性.
+
+    用于开启或者判断是否处于警告模式.
+ */
+
+/*!
+  \brief DLineEdit的构造函数
+  \a parent 参数被发送到 QWidget 构造函数。
  */
 DLineEdit::DLineEdit(QWidget *parent)
     : QWidget(parent)
@@ -64,9 +76,10 @@ DLineEdit::~DLineEdit()
 }
 
 /*!
- * \~chinese \brief DLineEdit::lineEdit返回 QLineEdit 对象
- * \~chinese \row 若 DLineEdit 不满足输入框的使用需求，请用此函数抛出的对象
- * \~chinese \return
+  \brief 返回 QLineEdit 对象.
+
+  若 DLineEdit 不满足输入框的使用需求，请用此函数抛出的对象
+  \return
  */
 QLineEdit *DLineEdit::lineEdit() const
 {
@@ -81,11 +94,7 @@ DLineEdit::DLineEdit(DLineEditPrivate &q, QWidget *parent)
     d_func()->init();
 }
 
-/*!
- * \~chinese \brief DLineEdit::setAlert设置是否开启警告模式
- * \~chinese \row 警告模式，开启警告模式，输入框内将显示警告颜色
- * \~chinese \param isAlert是否开启警告模式
- */
+
 void DLineEdit::setAlert(bool isAlert)
 {
     Q_D(DLineEdit);
@@ -93,9 +102,6 @@ void DLineEdit::setAlert(bool isAlert)
     d->control->setAlert(isAlert);
 }
 
-/*!
- * \~chinese \brief DLineEdit::alert返回当前是否处于警告模式
- */
 bool DLineEdit::isAlert() const
 {
     D_DC(DLineEdit);
@@ -108,12 +114,13 @@ void DLineEdit::showAlertMessage(const QString &text, int duration)
 }
 
 /*!
- * \~chinese \brief DLineEdit::showAlertMessage显示警告消息
- * \~chinese \row 显示指定的文本消息，超过指定时间后警告消息消失.
- * \~chinese \row \note 时间参数为-1时，警告消息将一直存在
- * \~chinese \param text警告的文本
- * \~chinese \param duration显示的时间长度，单位毫秒
- * \~chinese \param parent tooltip跟随
+  \brief 显示警告消息.
+
+  显示指定的文本消息，超过指定时间后警告消息消失.
+  \note 时间参数为-1时，警告消息将一直存在
+  \a text 警告的文本
+  \a duration 显示的时间长度，单位毫秒
+  \a follower tooltip跟随
  */
 void DLineEdit::showAlertMessage(const QString &text, QWidget *follower, int duration)
 {
@@ -122,10 +129,11 @@ void DLineEdit::showAlertMessage(const QString &text, QWidget *follower, int dur
 }
 
 /*!
- * \~chinese \brief DLineEdit::setAlertMessageAlignment 指定对齐方式
- * \~chinese \row 现只支持(下)左，(下)右，(下水平)居中， 默认左对齐.
- * \~chinese \row \note 参数为其他时，默认左对齐
- * \~chinese \param alignment 消息对齐方式
+  \brief 指定对齐方式.
+
+  现只支持(下)左，(下)右，(下水平)居中， 默认左对齐.
+  \note 参数为其他时，默认左对齐
+  \a alignment 消息对齐方式
  */
 void DLineEdit::setAlertMessageAlignment(Qt::Alignment alignment)
 {
@@ -140,7 +148,8 @@ Qt::Alignment DLineEdit::alertMessageAlignment() const
 }
 
 /*!
- * \~chinese \brief DLineEdit:: hideAlertMessage隐藏警告消息框
+  \brief 隐藏警告消息框.
+
  */
 
 void DLineEdit:: hideAlertMessage()
@@ -159,10 +168,11 @@ void DLineEdit:: hideAlertMessage()
 }
 
 /*!
- * \~chinese \brief DLineEdit::setLeftWidgets向输入框左侧添加控件
- * \~chinese \row 将 QList 里的控件插入到输入框的左侧
- * \~chinese \row \note 多次调用，只有最后一次调用生效
- * \~chinese \param list存储控件的列表
+  \brief 向输入框左侧添加控件.
+
+  将 QList 里的控件插入到输入框的左侧
+  \note 多次调用，只有最后一次调用生效
+  \a list 存储控件的列表
  */
 
 void DLineEdit::setLeftWidgets(const QList<QWidget *> &list)
@@ -193,10 +203,11 @@ void DLineEdit::setLeftWidgets(const QList<QWidget *> &list)
 }
 
 /*!
- * \~chinese \brief DLineEdit::setRightWidgets向输入框右侧添加控件
- * \~chinese \row 将 QList 里的控件插入到输入框的右侧
- * \~chinese \row \note 多次调用，只有最后一次调用生效
- * \~chinese \param list存储控件的列表
+  \brief 向输入框右侧添加控件.
+
+  将 QList 里的控件插入到输入框的右侧
+  \note 多次调用，只有最后一次调用生效
+  \a list 存储控件的列表
  */
 
 void DLineEdit::setRightWidgets(const QList<QWidget *> &list)
@@ -227,17 +238,19 @@ void DLineEdit::setRightWidgets(const QList<QWidget *> &list)
 }
 
 /*!
- * \~chinese \brief DLineEdit::setLeftWidgetsVisible是否隐藏输入框左侧控件
- * \~chinese \param visible是否隐藏
+  \brief 是否隐藏输入框左侧控件.
+
+  \a visible 是否隐藏
  */
 void DLineEdit::setLeftWidgetsVisible(bool visible)
 {
     Q_D(DLineEdit);
     d->leftWidget->setVisible(visible);
 }
-/**
- * \~chinese \brief DLineEdit::setRightWidgetsVisible是否隐藏输入框右侧控件
- * \~chinese \param visible是否隐藏
+/*!
+  \brief 是否隐藏输入框右侧控件.
+
+  \a visible 是否隐藏
  */
 void DLineEdit::setRightWidgetsVisible(bool visible)
 {
@@ -246,8 +259,9 @@ void DLineEdit::setRightWidgetsVisible(bool visible)
 }
 
 /*!
- * \~chinese \brief DLineEdit::setClearButtonEnabled 设置清除按钮是否可见
- * \~chinese \param enable true 按钮可见 false 按钮不可见
+  \brief 设置清除按钮是否可见.
+
+  \a enable true 按钮可见 false 按钮不可见
  */
 void DLineEdit::setClearButtonEnabled(bool enable)
 {
@@ -260,8 +274,9 @@ void DLineEdit::setClearButtonEnabled(bool enable)
 }
 
 /*!
- * \~chinese \brief DLineEdit::isClearButtonEnabled
- * \~chinese \return true 清除按钮可见 false 清除按钮不可见
+  \brief 返回清除按钮是否可见.
+
+  \return true 清除按钮可见 false 清除按钮不可见
  */
 bool DLineEdit::isClearButtonEnabled() const
 {
@@ -270,8 +285,9 @@ bool DLineEdit::isClearButtonEnabled() const
 }
 
 /*!
- * \~chinese \brief DLineEdit::setText 设置显示的文本
- * \~chinese \param text 显示的文本
+  \brief 设置显示的文本.
+
+  \a text 显示的文本
  */
 void DLineEdit::setText(const QString &text)
 {
@@ -280,8 +296,9 @@ void DLineEdit::setText(const QString &text)
 }
 
 /*!
- * \~chinese \brief DLineEdit::text
- * \~chinese \return 返回显示的文本
+  \brief 返回当前显示的文本.
+
+  \return 返回显示的文本
  */
 QString DLineEdit::text()
 {
@@ -290,7 +307,7 @@ QString DLineEdit::text()
 }
 
 /*!
- * \~chinese \brief DLineEdit::clear 清空编辑的内容
+  \brief 清空编辑的内容.
  */
 void DLineEdit::clear()
 {
@@ -299,8 +316,9 @@ void DLineEdit::clear()
 }
 
 /*!
- * \~chinese \brief DLineEdit::echoMode
- * \~chinese \return 返回回显的模式
+  \brief 返回输入框的回显模式.
+
+  \return 返回回显的模式
  */
 QLineEdit::EchoMode DLineEdit::echoMode() const
 {
@@ -309,8 +327,9 @@ QLineEdit::EchoMode DLineEdit::echoMode() const
 }
 
 /*!
- * \~chinese \brief DLineEdit::setEchoMode 设置回显的模式
- * \~chinese \param mode 回显的模式
+  \brief 设置回显的模式.
+
+  \a mode 回显的模式
  */
 void DLineEdit::setEchoMode(QLineEdit::EchoMode mode)
 {
@@ -319,10 +338,11 @@ void DLineEdit::setEchoMode(QLineEdit::EchoMode mode)
 }
 
 /*!
- * \~chinese \brief DLineEdit::setContextMenuPolicy
- * \~chinese \param policy 显示右键菜单的方式
- * \~chinese \row 转发实际变量 QLineEdit 的 ContextMenuEvent 消息
- * \~chinese \see QLineEdit::setContextMenuPolicy
+  \brief 设置行编辑控件的文本菜单策略.
+
+  \a policy 显示右键菜单的方式
+  转发实际变量 QLineEdit 的 ContextMenuEvent 消息
+  \sa QLineEdit::setContextMenuPolicy
  */
 void DLineEdit::setContextMenuPolicy(Qt::ContextMenuPolicy policy)
 {
@@ -331,8 +351,9 @@ void DLineEdit::setContextMenuPolicy(Qt::ContextMenuPolicy policy)
 }
 
 /*!
- * \~chinese \brief DLineEdit::speechToTextIsEnabled
- * \~chinese \return true 显示语音听写菜单项 false不显示
+  \brief 返回是否显示语音听写菜单项.
+
+  \return true 显示语音听写菜单项 false不显示
  */
 bool DLineEdit::speechToTextIsEnabled() const
 {
@@ -347,8 +368,9 @@ void DLineEdit::setPlaceholderText(const QString& placeholderText)
 }
 
 /*!
- * \~chinese \brief DLineEdit::setSpeechToTextEnabled 设置是否显示语音听写菜单项
- * \~chinese \param enable true显示 flase不显示
+  \brief 设置是否显示语音听写菜单项.
+
+  \a enable true显示 flase不显示
  */
 void DLineEdit::setSpeechToTextEnabled(bool enable)
 {
@@ -356,10 +378,10 @@ void DLineEdit::setSpeechToTextEnabled(bool enable)
     d->bSpeechToText = enable;
 }
 
-
 /*!
- * \~chinese \brief DLineEdit::textToSpeechIsEnabled
- * \~chinese \return true 显示语音朗读菜单项 false不显示
+  \brief 返回是否显示语音朗读菜单项.
+
+  \return true 显示语音朗读菜单项 false不显示
  */
 bool DLineEdit::textToSpeechIsEnabled() const
 {
@@ -368,8 +390,9 @@ bool DLineEdit::textToSpeechIsEnabled() const
 }
 
 /*!
- * \~chinese \brief DLineEdit::setTextToSpeechEnabled 设置是否显示语音朗读菜单项
- * \~chinese \param enable true显示 flase不显示
+  \brief 设置是否显示语音朗读菜单项.
+
+  \a enable true显示 flase不显示
  */
 void DLineEdit::setTextToSpeechEnabled(bool enable)
 {
@@ -378,8 +401,9 @@ void DLineEdit::setTextToSpeechEnabled(bool enable)
 }
 
 /*!
- * \~chinese \brief DLineEdit::textToTranslateIsEnabled
- * \~chinese \return true 显示文本翻译菜单项 false不显示
+  \brief 返回是否显示文本翻译菜单项.
+
+  \return true 显示文本翻译菜单项 false 不显示
  */
 bool DLineEdit::textToTranslateIsEnabled() const
 {
@@ -388,17 +412,64 @@ bool DLineEdit::textToTranslateIsEnabled() const
 }
 
 /*!
- * \~chinese \brief DLineEdit::setTextToTranslateEnabled 设置是否显示文本翻译菜单项
- * \~chinese \param enable true显示 flase不显示
+  \brief 设置是否显示文本翻译菜单项
+
+  \a enable true显示 flase不显示
  */
 void DLineEdit::setTextToTranslateEnabled(bool enable)
 {
     D_D(DLineEdit);
     d->bTextToTranslate = enable;
 }
+
 /*!
- * \~chinese \brief DLineEdit::eventFilter
- * \~chinese \row 该过滤器不做任何过滤动作，但会监控输入框的焦点状态，并发送信号 focusChanged()。
+  \brief DLineEdit::cutEnabled
+  \return true文本可剪切　false不可剪切
+ */
+bool DLineEdit::cutEnabled() const
+{
+    D_DC(DLineEdit);
+    return d->bEnableCut;
+}
+
+/*!
+  \brief DLineEdit::setCutEnabled 设置输入文本是否可拷贝
+  \a enabled　true输入文本可剪切　false不可剪切
+ */
+void DLineEdit::setCutEnabled(bool enable)
+{
+    D_D(DLineEdit);
+    d->bEnableCut = enable;
+}
+
+/*!
+  \brief DLineEdit::copyEnabled
+  \return true文本可拷贝　false不可拷贝
+ */
+bool DLineEdit::copyEnabled() const
+{
+    D_DC(DLineEdit);
+    return d->bEnableCopy;
+}
+
+/*!
+  \brief DLineEdit::setCopyEnabled 设置输入文本是否可拷贝
+  \a enabled　true输入文本可拷贝　false不可拷贝
+ */
+void DLineEdit::setCopyEnabled(bool enable)
+{
+    D_D(DLineEdit);
+    d->bEnableCopy = enable;
+}
+
+/*!
+  \brief 事件过滤器
+
+  \a watched 被监听的子控件指针， \a event 待过滤的事件 \a event 实例.
+
+  该过滤器不做任何过滤动作，但会监控输入框的焦点状态，并发送信号 focusChanged()。
+
+  \return 成功过滤返回 true，否则返回 false .
  */
 bool DLineEdit::eventFilter(QObject *watched, QEvent *event)
 {
@@ -412,6 +483,14 @@ bool DLineEdit::eventFilter(QObject *watched, QEvent *event)
         Q_EMIT focusChanged(false);
     } else if (watched == lineEdit() && event->type() == QEvent::KeyPress) {
         QKeyEvent *pKeyEvent = static_cast<QKeyEvent *>(event);
+
+        if (pKeyEvent == QKeySequence::Copy && !copyEnabled()) {
+            return true;
+        }
+        if (pKeyEvent == QKeySequence::Cut && !cutEnabled()) {
+            return true;
+        }
+
         if (pKeyEvent == QKeySequence::SelectAll) {
             QApplication::clipboard()->setText(lineEdit()->text(), QClipboard::Mode::Selection);
         }
@@ -453,6 +532,15 @@ bool DLineEdit::eventFilter(QObject *watched, QEvent *event)
         QLineEdit *pLineEdit = static_cast<QLineEdit*>(watched);
         QMenu *menu = pLineEdit->createStandardContextMenu();
 
+        for (QAction *action : menu->actions()) {
+            if (action->text().startsWith(QLineEdit::tr("&Copy")) && !copyEnabled()  ) {
+                action->setEnabled(false);
+            }
+            if (action->text().startsWith(QLineEdit::tr("Cu&t")) && !cutEnabled()) {
+                action->setEnabled(false);
+            }
+        }
+
         connect(menu, &QMenu::triggered, this, [pLineEdit](QAction *pAction) {
             if (pAction->text().startsWith(QLineEdit::tr("Select All"))) {
                 QApplication::clipboard()->setText(pLineEdit->text(), QClipboard::Mode::Selection);
